#!/usr/bin/python
#  MEMU Launcer GUI
#
#  WJB   30/ 1/14 First draft.
#
try:
    from tkinter.tix import *   # Python 3.x import
    from tkinter.constants import *
except ImportError:
    from Tix import *           # Python 2.x import
    from Tkconstants import *
import subprocess
import os
import sys

class Launcher:
    def __init__ (self, args):
        self.args = args
        self.root = Tk ()
        self.root.title ('MEMU Launcher')
        r = 0
        Label (self.root, text='Emulation').grid (row=r, column=0)
        self.em_mode = 'MTX'
        em = OptionMenu (self.root, command=self.ChooseEm)
        em.add_command ('MTX')
        em.add_command ('SDX')
        em.add_command ('CPM')
        em.grid (row=r, column=1, sticky='W')
        r += 1
        Label (self.root, text='Memory (KB)').grid (row=r, column=0, sticky='E')
        self.mem = Spinbox (self.root, from_=32, to=512, increment=32)
        self.mem.grid (row=r, column=1, sticky='EW')
        r += 1
        Label (self.root, text='Video size').grid (row=r, column=0, sticky='E')
        self.vid = Spinbox (self.root, from_=0, to=5)
        self.vid.delete (0, END)
        self.vid.insert (0, '1')
        self.vid.grid (row=r, column=1, sticky='EW')
        r += 1
        Label (self.root, text='Monitor size').grid (row=r, column=0, sticky='E')
        self.mon = Spinbox (self.root, from_=0, to=5)
        self.mon.grid (row=r, column=1, sticky='EW')
        r += 1
        Label (self.root, text='Mono Monitor').grid (row=r, column=0, sticky='E')
        self.mono_var = IntVar ()
        Checkbutton (variable=self.mono_var).grid (row=r, column=1, sticky='W')
        r += 1
        Label (self.root, text='Text Monitor').grid (row=r, column=0, sticky='E')
        f1 = Frame (self.root)
        f1.grid (row=r, column=1, sticky='W')
        self.tm_var = IntVar ()
        Radiobutton (f1, text='None', variable=self.tm_var, value=0).pack (side=LEFT)
        Radiobutton (f1, text='TH', variable=self.tm_var, value=1).pack (side=LEFT)
        Radiobutton (f1, text='Console', variable=self.tm_var, value=2).pack (side=LEFT)
        r += 1
        Label (self.root, text='Sound').grid (row=r,column=0, sticky='E')
        self.snd_var = IntVar ()
        Checkbutton (variable=self.snd_var).grid (row=r, column=1, sticky='W')
        r += 1
        Label (self.root, text='Keyboard Remap').grid (row=r, column=0, sticky='E')
        self.kbd_var = IntVar ()
        Checkbutton (variable=self.kbd_var).grid (row=r, column=1, sticky='W')
        r += 1
        Label (self.root, text='Tape Directory').grid (row=r, column=0, sticky='E')
        f2 = Frame (self.root)
        f2.grid (row=r, column=1, sticky='EW')
        Button (f2, text='...', command=self.BrowseTape).pack (side=RIGHT)
        self.tape = Entry (f2)
        self.tape.pack (side=LEFT, fill=X, expand=1)
        r += 1
        Label (self.root, text='Drive A Directory').grid (row=r, column=0, sticky='E')
        f3 = Frame (self.root)
        f3.grid (row=r, column=1, sticky='EW')
        Button (f3, text='...', command=self.BrowseDriveA).pack (side=RIGHT)
        self.drivea = Entry (f3)
        self.drivea.pack (side=LEFT, fill=X, expand=1)
        r += 1
        Label (self.root, text='Drive A Invert Case').grid (row=r, column=0, sticky='E')
        self.daic_var = IntVar ()
        Checkbutton (variable=self.daic_var).grid (row=r, column=1, sticky='W')
        r += 1
        Label (self.root, text='Run File').grid (row=r, column=0, sticky='E')
        f4 = Frame (self.root)
        f4.grid (row=r, column=1, sticky='EW')
        Button (f4, text='...', command=self.BrowseRun).pack (side=RIGHT)
        self.run = Entry (f4)
        self.run.pack (side=LEFT, fill=X, expand=1)
        r += 1
        Button (self.root, text='Cancel', command=self.Quit).grid (row=r, column=0)
        Button (self.root, text='OK', command=self.Launch).grid (row=r, column=1)
        self.root.mainloop ()

    def ChooseEm (self, em):
        self.em_mode = em;

    def BrowseTape (self):
        DirSelectDialog (self.root, command=self.ChooseTape).popup ()

    def ChooseTape (self, dir):
        print (dir)
        self.tape.delete (0,END)
        self.tape.insert (0, dir)

    def BrowseDriveA (self):
        DirSelectDialog (self.root, command=self.ChooseDriveA).popup ()

    def ChooseDriveA (self, dir):
        print (dir)
        self.drivea.delete (0,END)
        self.drivea.insert (0, dir)

    def BrowseRun (self):
        ExFileSelectDialog (self.root, command=self.ChooseRun).popup ()

    def ChooseRun (self, fn):
        self.run.delete (0,END)
        self.run.insert (0, fn)

    def Launch (self):
        if ( len (self.args) > 1 ):
            margs = self.args[1:]
        else:
            pdir = os.path.dirname (self.args[0])
            if ( os.path.exists (os.path.join (pdir, 'memu.exe')) ):
                margs = [os.path.join (pdir, 'memu.exe')]
            elif ( os.path.exists (os.path.join (pdir, 'memu')) ):
                margs = [os.path.join (pdir, 'memu')]
            else:
                margs = ['memu']
        if ( self.em_mode == 'SDX' ):
            margs.append ('-sdx')
        elif ( self.em_mode == 'CPM' ):
            margs.append ('-cpm')
        margs.extend (['-mem-blocks', '%d' % ( int (self.mem.get ()) / 16 )])
        vsize = int (self.vid.get ())
        if ( vsize > 0 ):
            margs.append ('-vid-win')
            for i in range (vsize -1):
                margs.append ('-vid-win-big')
        msize = int (self.mon.get ())
        if ( msize > 0 ):
            margs.append ('-mon-win')
            for i in range (msize - 1):
                margs.append ('-mon-win-big')
        if ( self.mono_var.get () ):
            margs.append ('-mon-win-mono')
        tmode = self.tm_var.get ()
        if ( tmode == 1 ):
            margs.append ('-mon-th')
        elif ( tmode == 2 ):
            margs.append ('-mon-console')
        if ( self.snd_var.get () ):
            margs.append ('-snd-portaudio')
        if ( self.kbd_var.get () ):
            margs.append ('-kbd-remap')
        tape_dn = self.tape.get ()
        if ( tape_dn ):
            margs.extend (['-tape-dir', tape_dn])
        drivea_dn = self.drivea.get ()
        if ( drivea_dn ):
            margs.extend (['-cpm-drive-a', drivea_dn])
        if ( self.daic_var.get () ):
            margs.append ('-cpm-invert-case')
        run_fn = self.run.get ()
        if ( run_fn ):
            margs.append (run_fn)
        print (margs)
        subprocess.Popen (margs)
        self.root.destroy ()

    def Quit (self):
        self.root.destroy ()

Launcher (sys.argv)
